confp
=====

A configuration management tool, very similar to https://github.com/kelseyhightower/confd using
Python and the Jinja2 templating language.

Configuration files are created as Jinja2 templates, pulling values from one or more backends, and
can be run continuously as a daemon or as a single-execution application.

Installation
------------

```bash
pip install confp
```

Configuration
-------------

TODO
